cnt.rulebase.rules.sentence\_segmentation package
=================================================

Submodules
----------

cnt.rulebase.rules.sentence\_segmentation.const module
------------------------------------------------------

.. automodule:: cnt.rulebase.rules.sentence_segmentation.const
    :members:
    :undoc-members:
    :show-inheritance:

cnt.rulebase.rules.sentence\_segmentation.sentence\_segmenter module
--------------------------------------------------------------------

.. automodule:: cnt.rulebase.rules.sentence_segmentation.sentence_segmenter
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cnt.rulebase.rules.sentence_segmentation
    :members:
    :undoc-members:
    :show-inheritance:
